@@ -114,6 +114,7 @@ SLVARS = [
     'forecast_surface_roughness',
     'free_convective_velocity_over_the_oceans',
     'friction_velocity',
+    'geopotential',
     'gravity_wave_dissipation',
     'high_cloud_cover',
     'high_vegetation_cover',
@@ -226,7 +227,7 @@ SLVARS = [
     'northward_turbulent_surface_stress',
     'ocean_surface_stress_equivalent_10m_neutral_wind_direction',
     'ocean_surface_stress_equivalent_10m_neutral_wind_speed',
-    'orography',
+    'orography',  # deprecated
     'peak_wave_period',
     'period_corresponding_to_maximum_individual_wave_height',
     'potential_evaporation',
